---
title: "Final Fantasy Japanese Playthrough: Part 1"
date: 2022-01-27T20:55:43-08:00
tags:
  - japanese
  - ff
---

> **Disclaimer:** There may be mistakes in the Japanese content in this post, I am not an expert. This is simply some of my personal notes that I am making public as a blog post. Use this as reference with caution.

Today I decided to try the original [*Final Fantasy*](https://en.wikipedia.org/wiki/Final_Fantasy_(video_game)) game for the Famicom from 1987 in Japanese as vocabulary practice (and for fun, of course).

In this post, I'll be first be quickly going over what I used to run the game, and then text that I went over and the vocabulary I gained from it.

### Setup

To play, I first downloaded the revision B game ROM from [WoWroMs.com](https://wowroms.com/en/roms/nintendo-entertainment-system/final-fantasy-japan/22274.html). Not surprisingly, it's absolutely *tiny*: the entire ROM is less than a megabyte.

To run it, I used RetroArch, an open source emulation frontend. You can get it from either their [website](https://www.retroarch.com/) and also [Steam](https://store.steampowered.com/app/1118310/RetroArch) for free.

RetroArch itself is not an emulator, however: it just provides the frontend and tools to use emulators. In order to load an emulator into RetroArch, you need to install a *core*. Personally, I use the *Mesen* NES/Famicom core. On the standard version of RetroArch available on their website, you can install new cores directly inside of RetroArch through the core downloader. However, due to Steam's limitations, on the Steam version this menu isn't available. Instead, you get cores buy getting the (free) DLC on Steam, all of which are listed on RetroArch's store page. The Mesen core I use is available on Steam [here](https://store.steampowered.com/app/1205330/RetroArch__Mesen/).

### Content

[![Final Fantasy Japanese opening text](../final-fantasy-1.png)](../final-fantasy-1.png)

I didn't spend too long on it, but I did read through the opening text (see screenshot) and get vocab from it.

The Famicom didn't have enough memory for kanji, so all the text is purely in kana (hiragana and katakana). Here's a transcription of the text as written in-game.

> このせかいは　あんこくにつつまれている
>
> かぜはやみ　うみはあれ　だいちはくさっていく
>
> しかし　ひとびとは１つのよげんをしんじ　それをまっていた
>
> このよ　あんこくにそまりしとき
>
> ４にんのひかりのせんし　あらわれん
>
> ながいぼうけんのすえ　４にんのわかものがこのちにたどりついた
>
> そしてそのてには　それぞれクリスタルにぎられていた

### Kanji and attempted translation

> この[世]{せ}[界]{かい}は　[暗]{あん}[黒]{こく}に[包]{つつ}まれている

***This world is wrapped in darkness.***

> [風]{かぜ}は[闇]{やみ}*　[海]{うみ}は[荒]{あ}れ　[大]{だい}[地]{じ}は[腐]{くさ}っていく

***The wind is dark,***

*I interpreted「やみ」as 闇, darkness, here. It's also possible that it's 止み (止む), to be stopped (the wind), but it doesn't really make sense considering the next section says that the seas are stormy.

***the seas are stormy, and the Earth is rotting away.***

It's also important to mention that between the line sections divided by spaces, the verbs that look like they're being nominalized (e.g. [荒]{あ}れ for [荒]{あ}れる) are actually grammatically acting like the て-form of the verb to string the sentence together. From what I've heard and seen, this is more literary and is done to make the the opening text sound more "epic."

> しかし　[人]{ひと}[々]{びと}は[１]{ひと}つの[予]{よ}[言]{げん}を[信]{しん}じ　それを[待]{ま}っていた

***However, the people believe one prophecy, and on it they waited.***

Again,「[信]{しん}じ」here is like the て-form, [信]{しん}て.

> この[世]{よ}、[暗]{あん}[黒]{こく}に[染]{そ}まりしとき

***In this world, tainted with darkness,***

Here, [染]{そ}まる is the passive form of [染]{そ}める, to dye. So literally, the world is *dyed* with darkness, which brings up imagery of a deep-rooted corruption. The only thing that I was confused about here was what exactly the conjugation「[染]{そ}まりしとき」is here. 

> [４]{よ}[人]{にん}の[光]{ひかり}の[戦]{せん}[士]{し}　[現]{あらわ}れん

***four warriors of light will appear.***

> [長]{なが}い[冒]{ぼう}[険]{けん}の[末]{すえ}　[４]{よ}[人]{にん}の[若]{わか}[者]{もの}がこの[地]{ち}に[辿]{たど}り[着]{つ}いた

***At the end of a long adventure, four young travelers finally arrived in this region,***

> そして　その[手]{て}にはそれぞれクリスタルが[握]{にぎ}られていた

***and in each of their hands was a crystal.***

### The official NES version

Now, let's see how accurate this was!

Here is the official NES version of the opening text.

[![Final Fantasy English opening text](../final-fantasy-2.png)](../final-fantasy-2.png)

> The world is veiled in darkness. The wind stops, the see is wild, and the earth begins to rot.
>
> The people wait, their only hope, a prophecy...
>
> 'When the world is in darkness Four Warriors will come...'
>
> After a long journey, four young warriors arrive, each holding an ORB.

Overall, I was pretty close, but I made a couple mistakes.

1.「やみ」was in fact 止み, to stop. (Drago, you were right!)

2. Because of the lack of quotations in the Japanese version, I didn't realize that one of the lines was actually a recitation of the prophecy.

3. 「そまりしとき」was actually 染まりし時, so *when* the world is becomes tainted with darkness, specifying the time condition for the prophecy. I didn't recognize the construction here of *verb nominalization* + し (nominalization of する) + 時. Because I didn't realize that this line was a direction quotation of the prophecy, I didn't pick up on this, even though I should have. What the し is doing here is that it's rather like 〜にする, and turns it from being simply *the time when the world is tainted with darkness*, 染まり時, to *the time when the world **becomes** tainted with darkness*.

### Conclusion

This was a really fun practice. I honestly need to spend more time consuming native Japanese material; I honestly study way less than I should and my vocabulary game isn't where it should be. I put all of the new/forgotten vocabulary terms from this into my [Anki](https://apps.ankiweb.net/) deck.

I think I might make this a series of blog posts on this website, making Japanese study overview of things I pick up from Final Fantasy as I slowly work through the game. If I actually go through with that, you'll be able to see a list of posts on the Final Fantasy [#ff](/tags/ff) tag page.

See you in the next post!
